@@ -1,9 +1,9 @@
 import os
 import itertools
-import time
 import multiprocessing as mp
 from functools import partial
-from typing import Tuple, List
+from typing import List
+import logging
 
 from tqdm import tqdm
 import cv2
@@ -16,6 +16,10 @@ __all__ = [
     'OpenSlideCzi'
 ]
 
+# Define logger.
+logger = logging.getLogger(__name__)
+logger.setLevel(logging.INFO)
+
 
 class OpenSlideCzi(object):
     """
@@ -78,6 +82,7 @@ class OpenSlideCzi(object):
         func = partial(check_tile, **{
             'data_mask': self.data_mask,
             'region_mask': self.region_mask,
+            'width': width,
         })
         # Load tiles.
         filtered = []
@@ -89,7 +94,7 @@ class OpenSlideCzi(object):
                 bar_format='{l_bar}{bar:20}{r_bar}{bar:-20b}'
             ):
                 filtered.append(result)
-        filtered = list(filter(None, filtered))
+        filtered = list(filter(lambda x: x is not None, filtered))
         return filtered
 
     def read_region(self, location, scale, size):
@@ -160,7 +165,7 @@ class OpenSlideCzi(object):
         tiles.sort()
         # Check tiles...
         if len(tiles) == 0:
-            print('No tiles found!')
+            logger.warning('No tiles found!')
             return None
         # Collect each column seperately and mash them together.
         all_columns = []
@@ -203,7 +208,8 @@ def polygon_to_mask(poly, x, y, width, downsample):
     return mask
 
 
-def check_tile(xy, data_mask, region_mask):
+def check_tile(xy, data_mask, region_mask, width):
+    __, (x, y) = xy 
     tile = Polygon([
         [x, y],
         [x+width, y],
